@@ -29,7 +29,6 @@
 #include "kateconfigplugindialogpage.h"
 #include "kateviewmanager.h"
 #include "kateapp.h"
-#include "katefilelist.h"
 #include "katesavemodifieddialog.h"
 #include "katemwmodonhddialog.h"
 #include "katesession.h"
@@ -63,6 +62,7 @@
 #include <KRecentFilesAction>
 #include <KToggleFullScreenAction>
 #include <KAboutData>
+#include <kwindowsystem.h>
 
 #include <QDragEnterEvent>
 #include <QEvent>
@@ -75,6 +75,7 @@
 //END
 
 uint KateMainWindow::uniqueID = 1;
+KateMwModOnHdDialog *KateMainWindow::s_modOnHdDialog=0;
 
 KateContainerStackedLayout::KateContainerStackedLayout(QWidget* parent)
   : QStackedLayout(parent)
@@ -180,7 +181,7 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
   KatePluginManager::self()->enableAllPluginsGUI (this, sconfig);
 
   // connect documents menu aboutToshow
-  documentMenu = (QMenu*)factory()->container("documents", this);
+  documentMenu = (QMenu*)factory()->container("go", this);
   connect(documentMenu, SIGNAL(aboutToShow()), this, SLOT(documentMenuAboutToShow()));
 
   documentsGroup = new QActionGroup(documentMenu);
@@ -200,6 +201,9 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
     int id = KateApp::self()->mainWindowID (this);
     m_documentModel->readSessionConfig( sconfig,
         QString("DocumentModel:MainWindow:%1").arg(id) );
+    // sync session config - or do we need an extra
+    // KateFileList::readSessionConfig() here too?
+    m_fileList->setSortRole(m_documentModel->sortRole());
 
     m_viewManager->restoreViewConfiguration (KConfigGroup(sconfig, sgroup) );
   }
@@ -277,12 +281,6 @@ void KateMainWindow::setupMainWindow ()
   //filelist = new KateFileList (this, m_viewManager, ft);
 //   m_fileList->readConfig(KConfigGroup(KGlobal::config(), "FileList"));
 
-#if 0
-  KateMDI::ToolView *t = createToolView("kate_fileselector", KMultiTabBar::Left, SmallIcon("document-open"), i18n("Filesystem Browser"));
-  fileselector = new KateFileSelector( this, m_viewManager, t, "operator");
-  connect(fileselector->dirOperator(), SIGNAL(fileSelected(const KFileItem&)), this, SLOT(fileSelected(const KFileItem&)));
-#endif
-
   // make per default the filelist visible, if we are in session restore, katemdi will skip this ;)
   showToolView (ft);
 }
@@ -312,6 +310,11 @@ void KateMainWindow::setupActions()
   connect( a, SIGNAL( triggered() ), KateDocManager::self(), SLOT( reloadAll() ) );
   a->setWhatsThis(i18n("Reload all open documents."));
 
+  a = actionCollection()->addAction( "file_close_orphaned" );
+  a->setText( i18n("Close Orphaned") );
+  connect( a, SIGNAL( triggered() ), KateDocManager::self(), SLOT( closeOrphaned() ) );
+  a->setWhatsThis(i18n("Close all documents in the file list that could not be reopened, because they are not accessible anymore."));
+  
   actionCollection()->addAction( KStandardAction::Close, "file_close", m_viewManager, SLOT( slotDocumentClose() ) )
   ->setWhatsThis(i18n("Close the current document."));
 
@@ -381,11 +384,11 @@ void KateMainWindow::setupActions()
   a = actionCollection()->addAction( "sessions_new" );
   a->setIcon( KIcon("document-new") );
   a->setText( i18nc("Menu entry Session->New", "&New") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionNew() ) );
+  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionNew() ), Qt::QueuedConnection );
   a = actionCollection()->addAction( "sessions_open" );
   a->setIcon( KIcon("document-open") );
   a->setText( i18n("&Open...") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionOpen() ) );
+  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionOpen() ), Qt::QueuedConnection );
   a = actionCollection()->addAction( "sessions_save" );
   a->setIcon( KIcon("document-save") );
   a->setText( i18n("&Save") );
@@ -396,12 +399,12 @@ void KateMainWindow::setupActions()
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAs() ) );
   a = actionCollection()->addAction( "sessions_save_default" );
   a->setIcon( KIcon("document-save-as") );
-  a->setText( i18n("Save As &Default...") );
+  a->setText( i18n("Save as &Default...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAsDefault() ) );
   a = actionCollection()->addAction( "sessions_manage" );
   a->setIcon( KIcon("view-choose") );
   a->setText( i18n("&Manage...") );
-  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionManage() ) );
+  connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionManage() ), Qt::QueuedConnection );
 
   // quick open menu ;)
   a = new KateSessionsAction (i18n("&Quick Open"), this);
@@ -474,14 +477,7 @@ bool KateMainWindow::queryClose()
   // and save docs if we really close down !
   if ( queryClose_internal () )
   {
-    KateApp::self()->sessionManager()->saveActiveSession(true, true);
-#ifdef __GNUC__
-#warning "kde4: dbus port"
-#endif
-#if 0
-    // detach the dcopClient
-    KateApp::self()->dcopClient()->detach();
-#endif
+    KateApp::self()->sessionManager()->saveActiveSession(true);
     return true;
   }
 
@@ -508,6 +504,12 @@ void KateMainWindow::slotNewToolbarConfig()
 }
 
 void KateMainWindow::slotFileQuit()
+{
+  // delay real shutdown outside of this, as we are inside menu action handling
+  QTimer::singleShot(0, this, SLOT(slotFileQuitDelayed()));
+}
+
+void KateMainWindow::slotFileQuitDelayed()
 {
   KateApp::self()->shutdownKate (this);
 }
@@ -679,12 +681,21 @@ void KateMainWindow::slotDropEvent( QDropEvent * event )
 
 void KateMainWindow::editKeys()
 {
-  KShortcutsDialog dlg ( KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsDisallowed, this );
+  KShortcutsDialog dlg ( KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this );
 
   QList<KXMLGUIClient*> clients = guiFactory()->clients();
 
-  foreach(KXMLGUIClient *client, clients)
-  dlg.addCollection ( client->actionCollection(), client->componentData().aboutData()->programName() );
+  foreach(KXMLGUIClient *client, clients) {
+#ifdef __GNUC__
+#warning there appear to be invalid clients after session switching    
+#endif
+//     kDebug(13001)<<"adding client to shortcut editor";
+//     kDebug(13001)<<client;
+//     kDebug(13001)<<client->actionCollection();
+//     kDebug(13001)<<client->componentData().aboutData();
+//     kDebug(13001)<<client->componentData().aboutData()->programName();
+    dlg.addCollection ( client->actionCollection(), client->componentData().aboutData()->programName() );
+  }
   /*
     dlg.insert( externalTools->actionCollection(), i18n("External Tools") );
   */
@@ -794,7 +805,7 @@ void KateMainWindow::slotOpenWithMenuAction(QAction* a)
   }
   else
   {
-    KMessageBox::error(this, i18n("Application '%1' not found!", openWith), i18n("Application not found!"));
+    KMessageBox::error(this, i18n("Application '%1' not found.", openWith), i18n("Application not found"));
   }
 }
 
@@ -821,11 +832,11 @@ void KateMainWindow::slotFullScreen(bool t)
 
 bool KateMainWindow::event( QEvent *e )
 {
-  uint type = e->type();
+/*  uint type = e->type();
   if ( type == QEvent::WindowActivate && modNotification )
   {
     showModOnDiskPrompt();
-  }
+  }*/
   return KateMDI::MainWindow::event( e );
 }
 
@@ -897,7 +908,7 @@ void KateMainWindow::updateCaption (KTextEditor::Document *doc)
   if ( !sessName.isEmpty() )
     sessName = QString("%1: ").arg( sessName );
 
-  setCaption( sessName + KStringHandler::lsqueeze(c, 64),
+  setCaption( sessName + c,
               m_viewManager->activeView()->document()->isModified());
 }
 
@@ -989,6 +1000,7 @@ void KateMainWindow::saveWindowConfig(const KConfigGroup &_config)
 
 void KateMainWindow::restoreWindowConfig(const KConfigGroup &config)
 {
+  setWindowState(Qt::WindowNoState);
   applyMainWindowSettings(config);
   restoreWindowSize(config);
   setWindowState( QFlags<Qt::WindowState>(config.readEntry("WindowState", int(Qt::WindowActive))) );
@@ -1011,4 +1023,34 @@ void KateMainWindow::slotUpdateHorizontalViewBar()
   }
 }
 
+void KateMainWindow::queueModifiedOnDisc(KTextEditor::Document *doc)
+{
+  if (!modNotification) return;
+
+  if (s_modOnHdDialog==0) {
+    DocVector list;
+    list.reserve( KateDocManager::self()->documents() );
+    list.append(doc);
+    
+    s_modOnHdDialog= new KateMwModOnHdDialog( list, this );
+    m_modignore = true;
+    KWindowSystem::setOnAllDesktops( s_modOnHdDialog->winId(), true);
+    bool res = s_modOnHdDialog->exec();
+    delete s_modOnHdDialog;
+    m_modignore = false;
+    return;
+  } else {
+    s_modOnHdDialog->addDocument(doc);
+    //if (qApp->activeWindow()) {
+//     s_modOnHdDialog->raise();
+//   #ifdef Q_WS_X11
+//   KWindowSystem::activateWindow (s_modOnHdDialog->winId ());
+//   KWindowSystem::raiseWindow (s_modOnHdDialog->winId ());
+//   KWindowSystem::setCurrentDesktop(
+//   #endif
+    return;
+  }
+}
+
+
 // kate: space-indent on; indent-width 2; replace-tabs on;
