@@ -88,10 +88,8 @@ K_EXPORT_PLUGIN(KateFileTemplatesFactory(KAboutData("katefiletemplates","katefil
 
 //BEGIN PluginViewKateFileTemplates
 PluginViewKateFileTemplates::PluginViewKateFileTemplates(KateFileTemplates *plugin, Kate::MainWindow *mainwindow):
-  Kate::PluginView(mainwindow),KXMLGUIClient(),m_plugin(plugin)
+  Kate::PluginView(mainwindow),Kate::XMLGUIClient(KateFileTemplatesFactory::componentData()),m_plugin(plugin)
 {
-  setComponentData (KateFileTemplatesFactory::componentData());
-  setXMLFile("plugins/katefiletemplates/ui.rc");
   QAction *a = actionCollection()->addAction("settings_manage_templates");
   a->setText(i18n("&Manage Templates..."));
   connect( a, SIGNAL( triggered(bool) ), plugin, SLOT( slotEditTemplate() ) );
@@ -908,7 +906,7 @@ void KateTemplateWizard::accept()
 
     templateUrl = dir + suggestion;
 
-    if ( QFile::exists( templateUrl.path() ) )
+    if ( QFile::exists( templateUrl.toLocalFile() ) )
     {
       if ( KMessageBox::warningContinueCancel( this, i18n(
           "<p>The file <br /><strong>'%1'</strong><br /> already exists; if you "
@@ -1019,7 +1017,7 @@ void KateTemplateWizard::accept()
   {
     if ( templateUrl.isLocalFile() )
     {
-      QFile file( templateUrl.path() );
+      QFile file( templateUrl.toLocalFile() );
          if ( file.open(QIODevice::WriteOnly) )
       {
         kDebug()<<"file opened with succes";
