@@ -23,7 +23,6 @@
 #include <QtGui/QPainter>
 #include <QtCore/QRegExp>
 #include <QtCore/QTimer>
-#include <Q3Frame>
 #include <QtGui/QResizeEvent>
 #include <QtGui/QMouseEvent>
 #include <QtGui/QWheelEvent>
@@ -45,24 +44,22 @@
 #define BLANK_LINE_HEIGHT 3
 #define HUNK_LINE_HEIGHT  5
 
-#define ANTIALIASING_MARGIN 1
-
 using namespace Diff2;
 
 KompareListViewFrame::KompareListViewFrame( bool isSource,
                                             ViewSettings* settings,
                                             KompareSplitter* parent,
                                             const char* name ):
-	Q3Frame ( parent, name ),
+	QFrame ( parent ),
 	m_view ( isSource, settings, this, name ),
 	m_label ( isSource?"Source":"Dest", this ),
 	m_layout ( this )
 {
 	setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored) );
 	m_label.setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
-	Q3Frame *bottomLine = new Q3Frame(this);
-	bottomLine->setFrameShape(Q3Frame::HLine);
-	bottomLine->setFrameShadow ( Q3Frame::Plain );
+	QFrame *bottomLine = new QFrame(this);
+	bottomLine->setFrameShape(QFrame::HLine);
+	bottomLine->setFrameShadow ( QFrame::Plain );
 	bottomLine->setSizePolicy ( QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed) );
 	bottomLine->setFixedHeight(1);
 	m_label.setMargin(3);
@@ -124,12 +121,11 @@ KompareListView::KompareListView( bool isSource,
 	setColumnWidthMode( COL_LINE_NO, Maximum );
 	setColumnWidthMode( COL_MAIN, Maximum );
 	setResizeMode( LastColumn );
-	setFrameStyle( Q3Frame::NoFrame );
+	setFrameStyle( QFrame::NoFrame );
 	setVScrollBarMode( Q3ScrollView::AlwaysOff );
 	setHScrollBarMode( Q3ScrollView::AlwaysOff );
 	setFocusPolicy( Qt::NoFocus );
 	setFont( m_settings->m_font );
-	setSpaces( m_settings->m_tabToNumberOfSpaces );
 	setFocusProxy( parent->parentWidget() );
 }
 
@@ -426,16 +422,6 @@ void KompareListView::slotApplyDifference( const Difference* diff, bool apply )
 		renumberLines();
 }
 
-void KompareListView::setSpaces( int spaces )
-{
-	m_spaces.truncate( 0 );
-	kDebug( 8104 ) << "tabToNumberOfSpaces: " << spaces << endl;
-	for ( int i = 0; i < spaces; i++ )
-		m_spaces += ' ';
-
-	triggerUpdate();
-}
-
 void KompareListView::wheelEvent( QWheelEvent* e )
 {
 	e->ignore(); // we want the parent to catch wheel events
@@ -669,9 +655,10 @@ void KompareListViewLineItem::paintCell( QPainter * p, const QColorGroup & /*cg*
 	// Paint darker lines around selected item
 	if ( diffItemParent()->isSelected() )
 	{
+		p->translate(0.5,0.5);
 		p->setPen( bg.dark(135) );
 		if ( this == parent()->firstChild() )
-			p->drawLine( 0, ANTIALIASING_MARGIN, width, ANTIALIASING_MARGIN );
+			p->drawLine( 0, 0, width, 0 );
 		if ( nextSibling() == 0 )
 			p->drawLine( 0, height() - 1, width, height() - 1 );
 	}
@@ -684,6 +671,7 @@ void KompareListViewLineItem::paintText( QPainter* p, const QColor& bg, int colu
 		QString textChunk;
 		int offset = listView()->itemMargin();
 		int prevValue = 0;
+		int charsDrawn = 0;
 		int chunkWidth;
 		QBrush changeBrush( bg, Qt::Dense3Pattern );
 		QBrush normalBrush( bg, Qt::SolidPattern );
@@ -710,7 +698,8 @@ void KompareListViewLineItem::paintText( QPainter* p, const QColor& bg, int colu
 //				kDebug(8104) << "TextChunk   = \"" << textChunk << "\"" << endl;
 //				kDebug(8104) << "c->offset() = " << c->offset() << endl;
 //				kDebug(8104) << "prevValue   = " << prevValue << endl;
-				textChunk.replace( QChar('\t'), kompareListView()->spaces() );
+				expandTabs(textChunk, kompareListView()->settings()->m_tabToNumberOfSpaces, charsDrawn);
+				charsDrawn += textChunk.length();
 				prevValue = m->offset();
 				if ( m->type() == Marker::End )
 				{
@@ -740,7 +729,7 @@ void KompareListViewLineItem::paintText( QPainter* p, const QColor& bg, int colu
 		{
 			// Still have to draw some string without changes
 			textChunk = m_text->string().mid( prevValue, qMax( 1, m_text->string().length() - prevValue ) );
-			textChunk.replace( QChar('\t'), kompareListView()->spaces() );
+			expandTabs(textChunk, kompareListView()->settings()->m_tabToNumberOfSpaces, charsDrawn);
 //			kDebug(8104) << "TextChunk   = \"" << textChunk << "\"" << endl;
 			QFont font( p->font() );
 			font.setBold( false );
@@ -763,6 +752,13 @@ void KompareListViewLineItem::paintText( QPainter* p, const QColor& bg, int colu
 	}
 }
 
+void KompareListViewLineItem::expandTabs(QString& text, int tabstop, int startPos) const
+{
+	int index;
+	while((index = text.indexOf(QChar(9)))!= -1)
+		text.replace(index, 1, QString(tabstop-((startPos+index)%4),' '));
+}
+
 KompareListViewDiffItem* KompareListViewLineItem::diffItemParent() const
 {
 	KompareListViewLineContainerItem* p = (KompareListViewLineContainerItem*)parent();
