@@ -1,12 +1,15 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 2 of
+  the License or (at your option) version 3 or any later version
+  accepted by the membership of KDE e.V. (or its successor approved
+  by the membership of KDE e.V.), which shall act as a proxy 
+  defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,24 +17,13 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **************************************************************************** */
 
-#include <glossary.h>
+#include "glossary.h"
 
+#include "stemming.h"
 #include "tbxparser.h"
 #include "project.h"
 #include "prefs_lokalize.h"
@@ -287,10 +279,10 @@ static void addTerms(Glossary* glo)
         "            <titleStmt>\n"
         "                <title>Your Team Glossary</title>\n"
         "            </titleStmt>\n"
+        "            <sourceDesc>\n"
+        "                <p>Lokalize</p>\n"
+        "            </sourceDesc>\n"
         "        </fileDesc>\n"
-        "        <encodingDesc>\n"
-        "            <p type=\"DCSName\">SYSTEM &quot;TBXDCSv05b.xml&quot;</p>\n"
-        "        </encodingDesc>\n"
         "    </martifHeader>\n"
         "    <text>\n"
         "        <body>\n"
@@ -462,6 +454,24 @@ QVariant GlossaryModel::data(const QModelIndex& index,int role) const
     return QVariant();
 }
 
+QModelIndex GlossaryModel::index (int row,int column,const QModelIndex& /*parent*/) const
+{
+    return createIndex (row, column);
+}
+
+int GlossaryModel::columnCount(const QModelIndex&) const
+{
+    return GlossaryModelColumnCount;
+}
+
+Qt::ItemFlags GlossaryModel::flags ( const QModelIndex & index ) const
+{
+/*    if (index.column()==FuzzyFlag)
+        return Qt::ItemIsSelectable|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled;*/
+    return QAbstractItemModel::flags(index);
+}
+
+
 //END MODEL general (GlossaryModel continues below)
 
 //BEGIN EDITING
@@ -514,45 +524,35 @@ QString Glossary::generateNewId()
 void Glossary::hashTermEntry(int index)
 {
     Q_ASSERT(index<termList.size());
-    int i=termList.at(index).english.size();
-    while(--i>=0)
+    foreach(const QString& term, termList.at(index).english)
     {
-        QStringList words=termList.at(index).english.at(i).split(' ',QString::SkipEmptyParts);
-        if (KDE_ISLIKELY( !words.isEmpty()) )
-        {
-            int j=words.size();
-            while(--j>=0)
-                wordHash.insert(words.at(j),index);
-        }
+        foreach(const QString& word, term.split(' ',QString::SkipEmptyParts))
+            wordHash.insert(stem(Project::instance()->sourceLangCode(),word),index);
     }
 }
 
 void Glossary::unhashTermEntry(int index)
 {
     Q_ASSERT(index<termList.size());
-    int i=termList.at(index).english.size();
-    while(--i>=0)
+    foreach(const QString& term, termList.at(index).english)
     {
-        QStringList words=termList.at(index).english.at(i).split(' ',QString::SkipEmptyParts);
-        if (KDE_ISLIKELY( !words.isEmpty() ))
-        {
-            int j=words.size();
-            while(--j>=0)
-                wordHash.remove(words.at(j),index);
-        }
+        foreach(const QString& word, term.split(' ',QString::SkipEmptyParts))
+            wordHash.remove(stem(Project::instance()->sourceLangCode(),word),index);
     }
 }
 
 
 void Glossary::remove(int i)
 {
-    unhashTermEntry(i);
-
     int pos;
     if ((pos=addedIds.indexOf(termList.at(i).id))!=-1)
         addedIds.removeAt(pos);
     removedIds.append(termList.at(i).id);
     termList.removeAt(i);
+    
+    wordHash.clear();
+    for (int i=0;i<termList.size();i++)
+        hashTermEntry(i);
 
     emit changed();//may be emitted multiple times in a row. so what? :)
 //     kDebug()<<"removedIds"<<removedIds.size();
@@ -576,6 +576,18 @@ void Glossary::append(const QString& _english,const QString& _target)
     emit changed();
 }
 
+void Glossary::clear()
+{
+    wordHash.clear();
+    termList.clear();
+    subjectFields=QStringList(QLatin1String(""));
+    //path.clear();
+    changedIds.clear();
+    removedIds.clear();
+    addedIds.clear();
+}
+
+
 bool GlossaryModel::removeRows(int row,int count,const QModelIndex& parent)
 {
     beginRemoveRows(parent,row,row+count-1);
